PROGRAM PB
!  This program, may be referred to as TERRACEPOND, is designed to take the output of daily meteorological values, runoff depth, and 
!  crop water-use coefficient from V2.F90 as inputs to a terrace channel.  The terrace channel is represented by a pond with up to 15 
!  LEVELS from the channel bottom up to the LEVEL below the top of the ridge.  This program simulates the operation of each of these 
!  levels on a daily basis to calculate the gross seepage of water from precipitation, irigation, and accumulated runoff into each of
!  the layers as well as overflow volume if the accumulated volume in the channel exceeds the depth of the outlet or lowest point on
!  the terrace ridge.  Each level section in the terrace channel is assigned a daily average seepage rate.  
!  The daily output from this program, Year,Month,Day,ET,Rainfall,(Seepdepth(i),i=1,(OFN+2)),KC,MUL,Inflow
!  serves as the input for the program, TERRACECHANNEL.F90 CB,F90), that operates each of the LEVELS in the terrace channel to simulate
!  the operations of the water budget including effects of flooding on KC to estimate percolation below the terrace channel for 
!  each of the LEVELS to complete the simulation of the operation of a terrace channel effect on runoff and percolation.  Then, results
!  are summed to get the total percolation below the terrace channel.  In all cases, it is assumed that all water each level moves only
!  vertically profile. 
  	IMPLICIT NONE
	INTEGER :: DAY,MONTH,YEAR,i,j,Overflowcount,m,k,L,mm,jj,n,II,KK,nn,KJ,&			
	  Seep1,Seep2,YEART,MONTHT,DAYT,DCount,OFN,JK,LI,LL,LN,IJ,IN,IK,&
	  L1,L2,SOIL
	REAL :: RUNOFF,RAINFALL,PDEPTH,ET,INFLOW,Evapvolume,Seepagevol,KC,KcT,&
		Rainvolume,Depthspillway,Overflow,PVolume,stage,Sumevapvol,&
		Sumrainvol,Sumoverflowvol,Sumseepvol,Inflowvol,Suminflowvol,&
		Deltavolume,Balance,Years,Incarea,Seepdepth,Depth,areaaccum,Volume,&
		Seeprate,Headexponent,Volumefull,WSarea,Startvolume,Sumraindepth,&
		SumETdepth,Averagerainvol,Averagevapvol,Averageseepvol,SUMEXCESSVOL,&
		Averageinflowvol,Averageoverflowvol,Averageraindepth,AverageETdepth,&
		Overflowduration,FCS,DepthUZ,SEEPDEPTHY,excess,SUMMEXCESSV,&
		ETT,RAINFALLT,INFLOWT,STAGET,SumMETD,SumMPrecD,SumMInfD,SumMETV,&
		SumMRainV,SumMInfV,SumMOvrV,SumMSeepV,DeltaStorage,Perc,PercT,Percvol,&
		SumPercvol,SumMPercV,Averagepercvol,MUL,MULT,Arearatio,YEARSTART,&
		YEAREND,WIDTH,TERRACESPACING,INCVOL,LENGTH,LZDF,EVAPVOL,SEEPVOL,&
		SEEPAGEVOLUME,AVERAGEEXCESS,CONTRIBAREA,STORAGEDEPTH
	Dimension Incarea(15)
	Dimension Seepdepth(15),SEEPDEPTHY(15),STORAGEDEPTH(15)   
	character(100) :: filename1,filename2,output,Filein,Fileout
	CHARACTER(19) FILE2, FILE19, FILE3
	CHARACTER(LEN=10) :: CI,DI
	CHARACTER(5) HRU,FL1
	Dimension Depth(15),Areaaccum(15),Volume(15),Seeprate(14),WIDTH(15)
	Dimension INCVOL(15)
	CHARACTER(4) TT,TP
	DO JK=1,5
	IF (JK.EQ.1) FILE2='LCBBTERRACEDATA.DAT'
	IF (JK.EQ.1) TT='LCBB'
	IF (JK.EQ.2) FILE2='LCFCTERRACEDATA.DAT' 
	IF (JK.EQ.2) TT='LCFC'
	IF (JK.EQ.3) FILE2='LOBBTERRACEDATA.DAT'
	IF (JK.EQ.3) TT ='LOBB'
	IF (JK.EQ.4) FILE2='LOFCTERRACEDATA.DAT'
	IF (JK.EQ.4) TT='LOFC' 	
	IF (JK.EQ.5) FILE2='GRBBTERRACEDATA.DAT' 
	IF (JK.EQ.5) TT='GRBB' 
	FILE3=TRIM(TT)//'DATA.OUT'
	open(UNIT=4,file=FILE2,status="unknown",IOSTAT=i)
	OPEN (UNIT=6,file=FILE3,status="unknown",blank='zero')  !Outputs terrace storage and surface area information.
	!Describes the phyical characteristics of the terraced field and terrace cross-section shape including overflow height from the bottom.
	READ(4,*) OFN,LENGTH,TERRACESPACING
	WSAREA=TERRACESPACING*LENGTH/43560.
	WRITE(6,90) TT,OFN+2,WSAREA
     90 FORMAT(A4,I4,F8.3)
	DO 20 LL=1,OFN+2
	READ(4,*) LN,DEPTH(LL),WIDTH(LL),SEEPRATE(LL)
	IF(LL.EQ.1) THEN	
	INCAREA(1)=(WIDTH(1)*LENGTH)/43560.
		AREAACCUM(1)=INCAREA(1)
		INCVOL(1) = 0.0
		VOLUME(1) = 0.0
		CONTINUE
	ELSE	
		INCAREA(LL)=(WIDTH(LL)-WIDTH(LL-1))*LENGTH/43560.	
		INCVOL(LL)=(DEPTH(LL)-DEPTH(LL-1))*WIDTH(LL-1)&
			*LENGTH/43560. ! ALL VOLUMES ARE IN ACRE-INCHES. 
		VOLUME(LL)=VOLUME(LL-1)+INCVOL(LL)
	END IF
	AREAACCUM(LL)=WIDTH(LL)*LENGTH/43560.
	STORAGEDEPTH(LL)= VOLUME(LL)/(TERRACESPACING*LENGTH/43560.)
	WRITE(6,91) LL,DEPTH(LL),WIDTH(LL),INCAREA(LL),AREAACCUM(LL),&
	        INCVOL(LL),VOLUME(LL),STORAGEDEPTH(LL)  !AREAACCUM IS IN ACRES, VOLUMES ARE IN ACRE-IN., STORAGEDEPTH INS IN INCHES.
	20	CONTINUE
     91 FORMAT(I3,2F7.2,5F12.4)
        WRITE(6,92)
     92 FORMAT(/,' No. D,in. W,feet    Incarea,ac&
         &  Accarea,ac  Incvol ac-in Vol,ac-in  Stor Depth,in.')
     	close(Unit=6)
	END DO	
	DO 3000 L1=1,5
! L1 = Terrace type 1 to 5
	IF (L1.EQ.1) FILE2='LCBBTERRACEDATA.DAT'
	IF (L1.EQ.2) FILE2='LCFCTERRACEDATA.DAT' 
	IF (L1.EQ.3) FILE2='LOBBTERRACEDATA.DAT'
	IF (L1.EQ.4) FILE2='LOFCTERRACEDATA.DAT'
	IF (L1.EQ.5) FILE2='GRBBTERRACEDATA.DAT' 
	IF (L1.EQ.1) TT='LCBB'
	IF (L1.EQ.2) TT='LCFC'
	IF (L1.EQ.3) TT ='LOBB'
	IF (L1.EQ.4) TT='LOFC' 	
	IF (L1.EQ.5) TT='GRBB' 
	open(UNIT=4,file=FILE2,status="unknown",IOSTAT=i)
	!Describes the phyical characteristics of the terraced field and terrace cross-section shape including overflow height from the bottom.
	READ(4,*) OFN,LENGTH,TERRACESPACING
	WSAREA=TERRACESPACING*LENGTH/43560.
	DO 30 LL=1,OFN+2
	READ(4,*) LN,DEPTH(LL),WIDTH(LL),SEEPRATE(LL)
	IF(LL.EQ.1) THEN	
	INCAREA(1)=(WIDTH(1)*LENGTH)/43560.
		AREAACCUM(1)=INCAREA(1)
		INCVOL(1) = 0.0
		VOLUME(1) = 0.0
		CONTINUE
	ELSE	
		INCAREA(LL)=(WIDTH(LL)-WIDTH(LL-1))*LENGTH/43560.	
		INCVOL(LL)=(DEPTH(LL)-DEPTH(LL-1))*WIDTH(LL-1)&
			*LENGTH/43560. ! ALL VOLUMES ARE IN ACRE-INCHES. 
		VOLUME(LL)=VOLUME(LL-1)+INCVOL(LL)
	END IF
	AREAACCUM(LL)=WIDTH(LL)*LENGTH/43560.
	STORAGEDEPTH(LL)= VOLUME(LL)/(TERRACESPACING*LENGTH/43560.)
	30	CONTINUE
	Arearatio=TERRACESPACING/WIDTH(OFN)
	Volumefull=Volume(OFN)
    DO 2000 L2=1,10
! L2=HRUs 1-10 used for each terrace type.
	STARTVOLUME=0.0
	Rainvolume=0.0
	Overflow=0.0
	Overflowcount=0
	Inflow=0.0
	Seepvol=0.0
	Sumevapvol=0.0
	Sumrainvol=0.0
	Sumoverflowvol=0.0
	Sumseepvol=0.0
	Suminflowvol=0.0
	Sumraindepth=0.0
	SumETdepth=0.0
	SUMEXCESSVOL=0.0
	Averagerainvol=0.0
	Averagevapvol=0.0
	Averageseepvol=0.0
	Averageinflowvol=0.0
	Averagepercvol=0.0
	Averageoverflowvol=0.0
	Averageraindepth=0.0
	AverageETdepth=0.0
	Seepagevol=0.0
	SumMETD = 0.0
	SumMPrecD = 0.0
	SumMInfD = 0.0
	SumMETV = 0.0
	SumMRainV = 0.0
	SumMInfV = 0.0
	SumMOvrV = 0.0
	SumMSeepV = 0.0
	SUMMEXCESSV=0.0
	DCount=0
	I=0
	II=0
	mm=0
	IK=0
	WRITE(CI,*) L2
	CI=ADJUSTL(CI)
	filename1='HRU'//TRIM(CI)
	FL1=TRIM(FILENAME1)
	open(1,filename1,STATUS='UNKNOWN') 
	!Output file from P95NEW that is the daily Input file here.
	WRITE(DI,*) L1
	DI=ADJUSTL(DI)
	filename2='TP'//TRIM(DI)//TRIM(CI)
	open(2,filename2,status="unknown",IOSTAT=i) ! NOTE:  Last record must look like this 999 0 0 0 0 0 0 0 0
	! NOTE:  Last record must look like this 999 0 0 0 0 0 0 0 0
	!Output file of daily results to pass to TERRACECHANNEL as the Input file.
	open(UNIT=3,file='monthly.out',status="unknown", blank='zero') !Output file for monthly values and water balance calculation results.
	Pvolume=0.0
	EXCESS=0.
	READ(1,*) FILE19, SOIL
	WRITE(2,95)FILE19,SOIL,TT
     95	FORMAT(A9,I3)
	READ(1,*)YEAR,MONTH,DAY,ET,RAINFALL,INFLOW,KC,MUL ! all water amounts are in inches
	YEARSTART=YEAR+((MONTH-1)/12.)+((DAY-1)/31.)/12.
!  Begin daily simulation loop and continue until input data stream end is reached.
	DO 1000 j=1,36500
		Do nn=1,OFN+1
		SEEPDEPTHY(NN)=SEEPDEPTH(NN)
		Seepdepth(nn) = 0.0
		End Do
	IK=0
	IF(PVOLUME.LT.0.) PVOLUME=0.
	READ(1,*)YEART,MONTHT,DAYT,ETT,RAINFALLT,INFLOWT,KCT,MULT     ! ET ,rainfall  and inflow are all in inches
	DCount=Dcount+1
	IF(INFLOW.EQ.0.) GOTO 101
! There is inflow, today 
	IF(PVOLUME.EQ.0) THEN 
		CONTRIBAREA=WSAREA
	ELSE
		II=0
		Do k=1,OFN+1
		IF(PVolume.LT.Volume(K)) exit  
			II=II+1
		END DO
		CONTRIBAREA=WSAREA-AREAACCUM(II)
	END IF
	Inflowvol=Inflow*CONTRIBAREA	! Inflowvol is in acre-IN
		RAINVOLUME = RAINFALL*(WSAREA-CONTRIBAREA) 
	!Assumes all rain on areas already ponded adds to maximum water accumulated in the pond area for the day.
		PVolume=PVolume+Inflowvol+RAINVOLUME !Pvolume is in acre-in. 
		If(PVolume.GT.Volume(OFN+1)) THEN	! There is A LARGE overflow event
			OVERFLOW= PVolume-(Volume(OFN)+0.5*(VOLUME(OFN+1)-VOLUME(OFN))) ! Overflowpotential is in acre-IN.
			PVolume = PVolume-OVERFLOW
			OVERFLOWCOUNT=OVERFLOWCOUNT+1
			Write(*,40)Year,Month,Day,Overflowcount,Overflow,&
			Inflowvol,RAINVOLUME,Pvolume
			IK=OFN
		ElseIF(PVOLUME.GT.VOLUME(OFN)) THEN  ! There is a moderate overflow event.
			Overflow=0.500*(PVOLUME-VOLUME(OFN))
			PVOLUME=PVOLUME-OVERFLOW
			OVERFLOWCOUNT=OVERFLOWCOUNT+1
			Write(*,40)Year,Month,Day,Overflowcount,Overflow,&
			Inflowvol,RAINVOLUME,Pvolume
			IK=OFN
		ELSE
			OVERFLOW=0.0
		End If
     40 Format ("OVERFLOW ",I5,3I3,4F9.3)		 
		GOTO 200
     101 IF(PVOLUME.GT.0.AND.RAINFALL.GT.0.0) THEN
!Determine surface area of pond on which rain falls in acres
			I=0
			Do K=1,OFN+1
			IF(PVolume.LE.Volume(K)) exit  
				I=I+1
			END DO
		RAINVOLUME=RAINFALL*AREAACCUM(I)
		PVOLUME=PVOLUME+RAINVOLUME
	ELSE
		RAINVOLUME=0.0  !Since there is no rain or inflow, there is no water that will be stored in the ponded area even if some is already there.
	END IF
! Determine starting depth and surface area for evaporation removal from the ponded area
     200 IF(PVOLUME.LE.0.0) THEN
		PVOLUME=0.0
		EVAPVOLUME=0.0
		PDEPTH = 0.0
		GOTO 500
		END IF
	IF(IK.EQ.OFN) GOTO 300
!IK SETS THE MAXIMUM LEVEL INUNDATED FOR THE DAY FROM INFLOW.
		IK=0
		Do K=1,OFN+1
		IF(PVolume.LE.Volume(K)) exit  
			IK=IK+1             
		END DO
	PDEPTH = DEPTH(IK)+(PVOLUME-VOLUME(IK))/AREAACCUM(IK)
! Determine amount of evaporation from the surface and check to see if a level is dried by evaporation.  
! Only one level will dry in one day because of relative depths of the level sections.
    300 IF(IK.GE.2) THEN
		IF((PDEPTH-ET).GT.(PDEPTH-DEPTH(IK)))THEN
		EVAPVOLUME=ET*AREAACCUM(IK)
		PDEPTH=PDEPTH-ET
		ELSE
		EVAPVOLUME=(PDEPTH-DEPTH(IK))*INCAREA(IK)&
			+(ET*AREAACCUM(IK-1))
		PDEPTH=PDEPTH-ET
		END IF
	ELSEIF(PDEPTH.LT.DEPTH(2).AND.PDEPTH.GE.ET)THEN
		EVAPVOLUME = ET*INCAREA(1)
		PDEPTH=PDEPTH-ET
	ELSEIF(PDEPTH.LT.ET) THEN
		EVAPVOLUME = PDEPTH*INCAREA(1)
		PDEPTH=0.
	END IF
	PVOLUME=PVOLUME-EVAPVOLUME	
	IF(PVOLUME.LT.0.) THEN
		EVAPVOLUME=EVAPVOLUME+PVOLUME
		PVOLUME=0.0
		PDEPTH=0.0
		END IF
	IF(EVAPVOLUME.GT.0.)&
	WRITE(*,122) Year,Month,Day,ET,PDEPTH,PVOLUME,EVAPVOLUME
    122 FORMAT("EVAPORATION ",3I4,4F7.3)
! Determine starting depth and depth and levels that are inundated for determination of seepage losses for a day.
		IF(PVOLUME.LE.0.) THEN
			SEEPAGEVOLUME=0.0
			PDEPTH = 0.0
			GOTO 500
		END IF
		KK=0
		Do K=1,OFN+1
		IF(PVolume.LT.Volume(K)) exit  
			KK=KK+1
		END DO
		PDEPTH = DEPTH(KK)+(PVOLUME-VOLUME(KK))/AREAACCUM(KK)
			SEEPDEPTH(KK)=SEEPRATE(KK)
		IF((PDEPTH-DEPTH(KK)).LT.SEEPRATE(KK)) THEN
			SEEPDEPTH(KK)=PDEPTH-DEPTH(KK)
			PDEPTH=DEPTH(KK)
		END IF
		SEEPAGEVOLUME=SEEPAGEVOLUME+SEEPDEPTH(KK)*INCAREA(KK)
		PVOLUME=PVOLUME-SEEPDEPTH(KK)*INCAREA(KK)
		IF(KK.EQ.1) GOTO 400
		Do k=KK-1,1,-1
			SEEPDEPTH(K)=SEEPRATE(K)
			SEEPAGEVOLUME=SEEPAGEVOLUME+SEEPDEPTH(K)*INCAREA(K)
			PVOLUME=PVOLUME-SEEPDEPTH(K)*INCAREA(K)
		END DO
		KK=0
		Do K=1,OFN+1
		IF(PVolume.LT.Volume(K)) exit  
			KK=KK+1
		END DO
		PDEPTH = DEPTH(KK)+(PVOLUME-VOLUME(KK))/AREAACCUM(KK)
		IF(PDEPTH.GT.DEPTH(OFN)) THEN
			OVERFLOW=OVERFLOW+(PDEPTH-DEPTH(OFN))*AREAACCUM(OFN)
			PDEPTH=DEPTH(OFN)
			PVOLUME=PVOLUME-(PDEPTH-DEPTH(OFN))*AREAACCUM(OFN)
			WRITE (*,11) YEAR,MONTH,DAY,I,DEPTH(I),PDEPTH,PVOLUME
		END IF
      11 FORMAT("EXTRA OVERFLOW AT END OF DAY ",4I4,3F6.2)
	IF(INFLOW.EQ.0.) GOTO 500
! CHECKS TO SEE WHICH AREAS NEED TO HAVE INFILTRATION FOR THE DAY ADDED TO SEEPAGE FOR THE DAY
! SINCE THE AREAS WERE INUNDATED BY THE INFLOW FOR THE DAY AND WILL BE EVALUATED AS FLOODED BY THE TERRACECHANNEL PROGRAM.
    400 DO IN=1,IK
		IF((RAINFALL.GT.INFLOW).AND.(SEEPDEPTHY(IN).EQ.0.)) THEN  !RAINFALL CONDITION
			SEEPDEPTH(IN)=SEEPDEPTH(IN)+(RAINFALL-INFLOW)
			EXCESS= EXCESS+(RAINFALL-INFLOW)*INCAREA(IN)
		END IF
		IF((INFLOW.GT.RAINFALL).AND.(SEEPDEPTHY(IN).EQ.0.)) THEN  !SNOWMELT CONDITION
			SEEPDEPTH(IN)=SEEPDEPTH(IN)-INFLOW
			EXCESS= EXCESS-INFLOW*INCAREA(IN)
		END IF
! EXCESS ACCOUNTS FOR THE INFILTRATION THAT OCCURS BUT IT IS NOT EXTRA SEEPAGE CAUSED BY THE PRESENCE OF THE TERRACE.
 			END DO
    500 IF(SEEPAGEVOLUME.GT.0.) WRITE (*,33) YEAR,MONTH,DAY,PDEPTH,PVOLUME,&
		SEEPAGEVOLUME
     33	FORMAT("SEEPAGE ",3I4,3F7.3)
        WRITE (2,10) Year,Month,Day,ET,Rainfall,&
		(Seepdepth(i),i=1,OFN+2),KC,MUL,Inflow,Inflowvol,Overflow  
             10 FORMAT(I4,1x,I2,1x,I2,25(F7.3))
		Sumrainvol=Sumrainvol+Rainvolume
		Sumevapvol=Sumevapvol+Evapvolume
		Sumoverflowvol=Sumoverflowvol+Overflow
		Sumseepvol=Sumseepvol+Seepagevolume+EXCESS
	IF(EXCESS.GT.0.) WRITE(*,99) YEAR,MONTH,DAY,SEEPAGEVOLUME,EXCESS
     99 FORMAT("EXCESS ",3I5,2F6.2)
		Suminflowvol=Suminflowvol+Inflowvol
		SUMEXCESSVOL=SUMEXCESSVOL+EXCESS
		Sumraindepth=sumraindepth+rainfall
		SumETdepth=SumETdepth+ET
		SumMPrecD = SumMPrecD + Rainfall
		SumMETD = SumMETD + ET
		SumMInfD = SumMInfD + Inflow
		SumMETV = SumMETV + Evapvolume
		SumMRainV = SumMRainV + Rainvolume
		SumMInfV = SumMInfV + Inflowvol
		SumMOvrV = SumMOvrV + Overflow
		SumMSeepV = SumMSeepV + Seepagevolume+EXCESS
		SUMMEXCESSV=SUMMEXCESSV + EXCESS
		Seepagevol=0.
		Overflow=0.
		Inflowvol=0.
		RAINVOLUME=0.
		EVAPVOLUME=0.
		SEEPAGEVOLUME=0.
		EXCESS=0.
		I=0
	If(MONTH/=MONTHT) Then
		DeltaStorage = Pvolume-StartVolume
		Startvolume=Pvolume
	Write (3,222) YEAR,MONTH,DCount,SumMETD,SumMInfD,SumMETV,&
		SumMRainV,SumMInfV,SumMOvrV,SumMSeepV,SUMMEXCESSV,DeltaStorage,&
		Pvolume,SumMOvrV/WSAREA 
    222 Format (I4,x,I2,x,I2,12(F8.3))
		YEAREND=YEAR+((MONTH-1)/12.)+((DAY/31.)/12.)
		IF (YEART < 1900) Then
		Write (2,*) '999 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0'
		Exit
		End If
		SumMETD = 0.0
		SumMPrecD = 0.0
		SumMInfD = 0.0
		SumMETV = 0.0
		SumMRainV = 0.0
		SumMInfV = 0.0
		SumMPercV = 0.0
		SumMOvrV = 0.0
		SumMSeepV = 0.0
		SUMMEXCESSV=0.0
		DCount=0
	End If
		Year=YearT
		Month=MonthT
		Day=DayT
		ET=ETT
		Rainfall=RainfallT
		Inflow=InflowT
		KC=KCT
		MUL=MULT
	1000 CONTINUE
		YEARS=YEAREND-YEARSTART
		Deltavolume=Pvolume-Startvolume
		Balance = Sumrainvol +Suminflowvol+SUMEXCESSVOL-Sumevapvol-Sumseepvol-&
			Sumoverflowvol-Deltavolume
	Write (3,25) YEARS
     25 FORMAT('   Volumes for',F4.0,' years in acre-inches and&
                           & Overflows = Number of Days')
	Write (3,26) FL1,TT
     26 FORMAT(2A5,'  Inflow    Prec.+Irr.  Evap.&
        &   Seepage InfilB4Inun. Overflow  Deltavol  Balance Overflows')
	Write (3,27) Suminflowvol,Sumrainvol,Sumevapvol,Sumseepvol,Sumexcessvol,&
				Sumoverflowvol,Deltavolume,Balance,overflowcount
     27 FORMAT('Total      ',f8.2,7(F10.2),2x,I4)
		Averagerainvol=Sumrainvol/Years
		Averagevapvol=Sumevapvol/Years
		Averageseepvol=Sumseepvol/Years
		Averageinflowvol=Suminflowvol/Years
		Averageoverflowvol=Sumoverflowvol/Years
		AVERAGEEXCESS=SUMEXCESSVOL/YEARS
		Averageraindepth=Sumraindepth/Years
		AverageETdepth=SumETdepth/Years
		Write (3,50) Averageinflowvol,Averagerainvol,Averagevapvol,&
			Averageseepvol,AVERAGEEXCESS,Averageoverflowvol
     50 FORMAT('Average      ',F7.3,5(F10.3))
	        Averagerainvol=Sumrainvol/Years/WSAREA*53.333
		Averagevapvol=Sumevapvol/Years/WSAREA*53.333
		Averageseepvol=Sumseepvol/Years/WSAREA*53.333
		Averageinflowvol=Suminflowvol/Years/WSAREA*53.333
		Averageoverflowvol=Sumoverflowvol/Years/WSAREA*53.333
		AVERAGEEXCESS=SUMEXCESSVOL/YEARS/WSAREA*53.333
		Averageraindepth=Sumraindepth/Years/WSAREA*53.333
		AverageETdepth=SumETdepth/Years/WSAREA*53.333
		Write (3,55) Averageinflowvol,Averagerainvol,Averagevapvol,&
			Averageseepvol,AVERAGEEXCESS,Averageoverflowvol
     55 FORMAT('Ac-ft/mi2-yr ',F7.3,5(F10.3))			
		WRITE (3,60)
     60 FORMAT(' ',/,'NOTE: InfilB4Inun. = Infiltration in terrace&
	& pondage levels that occurs during an inflow event',/,"on those&
	& levels that are subsequently inundated by inflow. &
	&It is added to the day's seepage on",/,'those levels that were&
	& not inundated before the inflow event because TERRACECHANNEL assumes&
	& that',/,"the area is submerged if seepage is greater than zero. &
	&TERRACEPOND accounts for the evaporative",/,"losses for the day from &
	&the surface and evapotranspiration is 0 for the day in TERRACECHANNEL."&
	&,//,"Column Headings are as follows: Year, Mo., DaysinMo, SumET, &
	&SumInflowDepth",/,&
	&"SumETVolume, SumRainV, SumInfiltrationV.,&
	& SumOverflowV, SumSeepageV ",/,&
	&"SumEXCESSV, DeltaStorage4Mo,StoredVolumeAtEndOfMo, SumOverflowDepth")
	WRITE(2,70) filename2,Averageinflowvol,Averageoverflowvol
     70	FORMAT(A10,2F8.3)
	Sumrainvol=0.
	Sumevapvol=0.
	Sumseepvol=0.
	Suminflowvol=0.
	Sumoverflowvol=0.
	SUMEXCESSVOL=0.
	Sumraindepth=0.
	SumETdepth=0.
	STARTVOLUME=0.0
	Rainvolume=0.0
	Overflow=0.0
	Overflowcount=0
	Inflow=0.0
	Seepvol=0.0
	Sumevapvol=0.0
	Sumrainvol=0.0
	Sumoverflowvol=0.0
	Sumseepvol=0.0
	Suminflowvol=0.0
	Sumraindepth=0.0
	SumETdepth=0.0
	SUMEXCESSVOL=0.0
	Averagerainvol=0.0
	Averagevapvol=0.0
	Averageseepvol=0.0
	Averageinflowvol=0.0
	Averagepercvol=0.0
	Averageoverflowvol=0.0
	Averageraindepth=0.0
	AverageETdepth=0.0
	Seepagevol=0.0
	SumMETD = 0.0
	SumMPrecD = 0.0
	SumMInfD = 0.0
	SumMETV = 0.0
	SumMRainV = 0.0
	SumMInfV = 0.0
	SumMOvrV = 0.0
	SumMSeepV = 0.0
	SUMMEXCESSV=0.0
	DCount=0
	I=0
	II=0
	mm=0
	IK=0	
	close(Unit=1)	
	close(Unit=2) 
   	close(Unit=3)
	close(Unit=4)
   2000	CONTINUE
   3000 CONTINUE
	stop
	end Program PB

					
